/* This file is part of the KDE project
   Copyright (C) 2009-2010 Adam Pigg <adam@piggz.co.uk>
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KEXIRELATIONDESIGNFACTORY_H
#define KEXIRELATIONDESIGNFACTORY_H

#include <KoShapeFactoryBase.h>


class KexiRelationDesignFactory : public KoShapeFactoryBase {
    public:
        KexiRelationDesignFactory( QObject *parent );
        virtual KoShape *createDefaultShape(KoResourceManager *documentResources = 0) const;
        virtual bool supports(const KoXmlElement & e, KoShapeLoadingContext &context) const;
};

#endif // KEXIRELATIONDESIGNFACTORY_H
